#ifdef __CLING__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;
#pragma link off all namespaces;

#pragma link C++ nestedclass;

#pragma link C++ namespace TMVA::Experimental::SOFIE;
#pragma link C++ class TMVA::Experimental::SOFIE::RModel_Base+;
#pragma link C++ class TMVA::Experimental::SOFIE::RModel-;
#pragma link C++ class TMVA::Experimental::SOFIE::ROperator+;
#pragma link C++ struct TMVA::Experimental::SOFIE::InitializedTensor+;
#pragma link C++ struct TMVA::Experimental::SOFIE::TensorInfo+;
#pragma link C++ struct TMVA::Experimental::SOFIE::InputTensorInfo+;
#pragma link C++ struct TMVA::Experimental::SOFIE::Dim+;
#pragma link C++ struct TMVA::Experimental::SOFIE::GNN_Data+;

#endif
